function check_2mass_paths(conf)
%CHECK_2MASS_PATHS
% Helper function for "sort_2mass_JHK.m" and "sort_2mass_HKJ.m"
% Tests if settings in load_2mass_settings.m (previously loaded in
% parameter "conf") are correct and if all files and programs needed for
% 2MASS star catalog preprocessing are accessible.
% Usage: 
%     conf = load_2mass_settings();
%     check_2mass_paths(conf);
%
% Copyright (C) 2019 INPE - Instituto Nacional de Pesquisas Espaciais.
% This is free software - see file LICENSE.txt for terms and conditions.

% Code written by Marcio A. A. Fialho.

endmsg = 'See file "01readme.txt" for instructions.';

% Checks the existence of the folder used to store preprocessed
% catalog sections
if exist(conf.PSC_mat_path, 'dir') == 0
    error(['Folder "%s", with preprocessed catalog sections, ' ...
        'not found!\n' endmsg], conf.PSC_mat_path);
end

% Checks the existence of the folder used to store preprocessed
% catalog sections
if exist(conf.PSC_sortcat_path, 'dir') == 0
    error(['Folder "%s" not found!\n' ...
        'A place to store catalog sections sorted by magnitude' ...
        ' is needed!\n' endmsg], conf.PSC_sortcat_path);
end

% Checks if each individual preprocessed section can be found:
%  57 sections in the southern hemisphere:
for k=0:56
    filename = [conf.PSC_mat_path 'psc_a' num2alfcount(k) '.mat'];
    if exist(filename, 'file') == 0
        error(['File "%s" not found.\n'...
            'Make sure settings in "load_2mass_settings.m" are ' ...
            'correct and that you have run "convert_all_psc.m".' ...
            endmsg], filename);
    end
end
%  35 sections in the northern hemisphere:
for k=0:34
    filename = [conf.PSC_mat_path 'psc_b' num2alfcount(k) '.mat'];
    if exist(filename, 'file') == 0
        error(['File "%s" not found.\n'...
            'Make sure you have downloaded all gzipped sections of '...
            'the 2-MASS star catalog.\n' endmsg], filename);
    end
end

end

