function conf = load_2mass_settings
%LOAD_2MASS_SETTINGS
% User modifiable configuration function with paths to use for source
% star catalog, saving intermediate data and executable program names.
%
% Syntax:
%    mysettings = load_2mass_settings;
%
% where mysettings is a struct with configuration data returned by this
% function.
%
% Note: Modify this function according to your environment, preferences
%       and needs.
%
% Copyright (C) 2019 INPE - Instituto Nacional de Pesquisas Espaciais.
% This is free software - see file LICENSE.txt for terms and conditions.

% Original version of this file written by Marcio A. A. Fialho.


% Set this flag to true to delete decompressed 2-MASS catalog sections and
% containing folder (if empty) automatically after processing - useful for
% reclaiming disk space
conf.remove_tmp_files = true;

% Path to 2MASS PSC (Point Source Catalog) sections in gzip format
%  Use './' (Unix) or '.\' (Windows) if you plan to use the current folder
%  for that purpose.
%  This string must end with a slash '/' (Unix) or a backslash '\'
%  (Windows) and must not have blank spaces inside.
conf.PSC_src_path = 'f:\2mass\allsky\';

% Path to 2MASS PSC preprocessed .mat files
%  Use './' (Unix) or '.\' (Windows) if you plan to use the current folder
%  for that purpose.
%  This string must end with a slash '/' (Unix) or a backslash '\'
%  (Windows) and must not have blank spaces inside.
conf.PSC_mat_path = 'c:\2mass_mat\';

% Path to 2MASS PSC sorted catalog path
%  Use './' (Unix) or '.\' (Windows) if you plan to use the current folder
%  for that purpose.
%  This string must end with a slash '/' (Unix) or a backslash '\'
%  (Windows) and must not have blank spaces inside.
conf.PSC_sortcat_path = 'f:\2mass\data\';

% Path to temporary files
%  Use './' (Unix) or '.\' (Windows) if you plan to use the current folder
%  for that purpose.
%  This string must end with a slash '/' (Unix) or a backslash '\'
%  (Windows) and must not have blank spaces inside.
conf.PSC_temp_path = 'f:\2mass\tmp\';

% Unzip program - 7Zip
%  Fully qualified name with path of the 7-Zip command line executable.
%  Notice: Do not enclose with double-quotes or use escape characters.
conf.Unzip7ZipProg = 'c:\Program Files\7-Zip\7z.exe';

% Conversion program read_2mass_mat.exe, built from read_2mass_mat.c.
%  For the convenience of the reader, this program is also available
%  precompiled for MS-Windows at the prebuilt\win\ folder.
%  Default location is the current directory (folder), but the user can
%  change this. The commented lines below give an example on how to do this
%  (in that case, do not forget to comment (disable) the last line):
%    conf.convProg = ...
%        'f:\STRLimits_paper\code\2mass\prebuilt\win\read_2mass_mat.exe';
conf.convProg = '.\read_2mass_mat.exe';

end