function setup_octave_savemat()
%function setup_octave_savemat()
% If running GNU-OCTAVE, sets default mode used to save .mat files.
% User editable - If you modify, please state that this file was modified
%                 before distributing it!
%
% Copyright (C) 2019 INPE - Instituto Nacional de Pesquisas Espaciais.
% This is free software - see file LICENSE.txt for terms and conditions.

% Tested with Matlab R2015b and GNU Octave 5.1.0 running on Windows.
% Code written by Marcio A. A. Fialho.


% If running GNU-Octave
if isoctave()
    
    % The default mode used by Octave to save .mat files is '-text',
    % which is too slow, bulky and not compatible with Matlab, so
    % we specify another format. Two options are shown below:
    
    % Use this option if the .mat files need to be readable by Matlab:
    %  Sets the default format to use for future .mat files as MATLAB's
    %  v6 binary data format (Matlab v5 and later).
    %new_save_format = '-v6'; 
    
    % Use this option if you need to save disk space:
    %  Sets the default format to use for future .mat file as Octave compressed
    %  binary files (not compatible with MATLAB).
    new_save_format = '-binary -z'; 
        
    % Query current data format
    cur_format = save_default_options();
    
    if strcmp(new_save_format, cur_format) ~= true
        msg = ['IMPORTANT: Setting Octave default .mat format used' ...
            ' in the save command to ''' new_save_format '''.\n' ...
            ' To restore previous behavior use this command:\n'...
            '    save_default_options(''' cur_format ''');\n'];
        fprintf(msg);
    end
    
    save_default_options(new_save_format);
end

end