function numstars = sort_2mass_JHK
%numstars = sort_2mass_JHK
% sorts the 2-MASS star catalog by J, H and K_s magnitudes, declination,
% and right ascension, in that order of priority.
% Saves the sorted catalog in 20 sections, each roughly the same size.
%
% Copyright (C) 2019 INPE - Instituto Nacional de Pesquisas Espaciais.
% This is free software - see file LICENSE.txt for terms and conditions.

% Code written by Marcio A. A. Fialho.

t_start = tic;

conf = load_2mass_settings;
check_2mass_paths(conf);

% If running GNU-Octave, sets default format to use in .mat files
setup_octave_savemat();

numstars = 0;

magfilter_J = [...
    -inf,...
    12.5750, 13.4930, 14.0390, 14.4320, 14.7400,...
    14.9950, 15.2130, 15.4040, 15.5740, 15.7260,...
    15.8650, 15.9930, 16.1100, 16.2180, 16.3170,...
    16.4090, 16.4970, 16.5920, 16.7220, +inf];

nsections = size(magfilter_J, 2) - 1;
for k=1:nsections
    t1 = tic;
    section_name = sprintf('psc_JHK%.2d', k);
    fprintf('Extracting section %d (%s) from 2MASS with %f < J <= %f\n',...
        k, section_name, magfilter_J(k), magfilter_J(k+1));
    
    % Extracts and sorts section by J, H, Ks magnitudes:
    eval([section_name ...
        ' = sort_2mass_JHK_sub(conf, magfilter_J(k), magfilter_J(k+1));']);
    
    % Information:
    n = eval(['size(' section_name ', 1);']);
    numstars = numstars + n;
    fprintf('%d stars in this J magnitude range.\n', n);
    
    % Saves catalog section ordered by J, H, Ks magnitudes:
    file_JHK = [conf.PSC_sortcat_path section_name '.mat'];
    fprintf('Saving section %d to file %s\n', k, file_JHK);
    eval(['save (''' file_JHK ''', ''' section_name ''');']);
    
    % Cleanup and message
    eval(['clear ' section_name]);
    fprintf('Processing section %d took %f seconds.\n\n', k, toc(t1));
end

fprintf('%d stars processed.\n', numstars);
fprintf('Time spent in %s = %f seconds.\n', mfilename, toc(t_start));

end