% Script used to compute values shown in Table 1 of the "Theoretical
% Limits of Star Sensor Accuracy" journal article.
%
% Copyright (C) 2017-2019 INPE - Instituto Nacional de Pesquisas Espaciais.
% This is free software - see file LICENSE.txt for terms and conditions.

% Code written by Marcio A. A. Fialho.


% This script generates the values shown in Table 1 (section 3.2 in the
% journal article), being based on plotFig6.m.
% See plotFig6.m and calc_star_celb.m for the various parameters
% controlling how the plots and data are generated.
clear;
close all;

% List of stars
starnames = {'Vega', '1757132', 'Sun', 'KF06T2', 'VB8'};
starnameprefix = {'', 'star ', 'the ', 'star ', 'star '};
fitsfiles = {...
    'alpha_lyr_stis_008', ... % basename of FITS file having Vega spectrum
    '1757132_stis_004', ...
    'sun_reference_stis_002', ... % FITS file with Sun spectrum
    'kf06t2_stisnic_004', ...
    'vb8_stisnic_006'};
pathToFITSFiles = 'calspec/'; % Where to find all those FITS files

% Default parameters for B-V computations
params_BV.band_order = -1; % Band V is at longer wavelengths than band B.
params_BV.plotlist = [false, false, false]; % no plots.
params_BV.diam = 0.1; % aperture diameter = 10 cm.
params_BV.t = 0.1; % integration time = 100 ms.

% Default parameters for H-Ks computations
params_HK.band_order = 1; % Band H is at shorter wavelengths than band K_s.
params_HK.plotlist = [false, false, false]; % no plots.
params_HK.diam = 0.1; % aperture diameter = 10 cm.
params_HK.t = 0.1; % integration time = 100 ms.


% Doing computation:
fprintf('Computing values shown in Table 1');

for k=1:5    
    fprintf('\nFor %s%s using B-V color indexes:\n', ...
        starnameprefix{k}, starnames{k});
    fitsfilename = [pathToFITSFiles fitsfiles{k} '.fits'];
    calc_star_celb(starnames{k}, fitsfilename, 'V', 'B', params_BV);
        
    fprintf('\nFor %s%s using H-K_s color indexes:\n', ...
        starnameprefix{k}, starnames{k});
    fitsfilename = [pathToFITSFiles fitsfiles{k} '.fits'];
    calc_star_celb(starnames{k}, fitsfilename, 'H', 'K', params_HK);    
end

disp('Done.');