% Script used to process the Tycho-2 star catalog for the plotFig7.m
% script.
%
% Copyright (C) 2019 INPE - Instituto Nacional de Pesquisas Espaciais.
% This is free software - see file LICENSE.txt for terms and conditions.

% Code written by Marcio A. A. Fialho.

clear;
close all;

t1 = tic;
catfile_Tyc2 = 'outputs/tycho2.mat';
destfile = 'outputs/Tycho2_out.mat';

% If running GNU-Octave, sets default format to use in .mat files
setup_octave_savemat();

if exist(catfile_Tyc2, 'file') == false
    src_cat_file = 'tycho2/tyc2.dat'; % Source star catalog.
    fprintf('Preprocessed Tycho-2 catalog (file %s) not found!\n',...
        catfile_Tyc2);
    disp('Trying to generate it from the main Tycho-2 star Catalog.');
    
    % Check if all catalog sections exist
    for k=0:19
        src_cat_file_sect = sprintf('%s.%.2d', src_cat_file, k);
        if exist(src_cat_file_sect, 'file') == 0
             error(['File %s not found!\n' ...
            'Download tyc2.dat.00.gz to tyc2.dat.19.gz from ' ...
            'ftp://cdsarc.u-strasbg.fr/pub/cats/I/259,\n' ...
            'unzip them all to the "tycho2/" folder and run this ' ...
            'script again.\n' 'For more details, see '...
            'https://www.cosmos.esa.int/web/hipparcos/tycho-2\n'],...
            src_cat_file_sect); %#ok<SPERR>
        end
    end

    % Preprocessing star catalog
    disp('Preprocessing star catalog - This may take a while.')
    [Tyc2, badrows_tyc2] = readTycho2(src_cat_file);
    % Description of fields:
    %   tyc2(:,1) => Tycho-2 catalog numbers
    %   tyc2(:,2) => Right Ascensions in degrees
    %   tyc2(:,3) => Declinations in degrees
    %   tyc2(:,4) => BT magnitudes
    %   tyc2(:,5) => VT magnitudes
        
    % Saving to file.
    fprintf('Saving star catalog to %s.\n', catfile_Tyc2);
    save(catfile_Tyc2, 'Tyc2', 'badrows_tyc2');
    disp('Done star catalog preprocessing.');
else
    fprintf('Loading preprocessed Tycho-2 catalog (file %s).\n',...
        catfile_Tyc2);
    load(catfile_Tyc2);
end

% Processing data from Tycho-2 catalog
disp ('Processing data from Tycho-2 star catalog');
outputs_Tyc2 = lower_bound_from_starcat('Tycho2');

save(destfile, 'outputs_Tyc2');

dt1 = toc(t1);
fprintf('Script %s took %f seconds.\n', mfilename, dt1);
disp('Done.');

