% Script used to generate two plots shown in Figure 6 of the journal
% article.
%
% Copyright (C) 2017-2019 INPE - Instituto Nacional de Pesquisas Espaciais.
% This is free software - see file LICENSE.txt for terms and conditions.

% Code written by Marcio A. A. Fialho.

clear;
close all;

fprintf('Running plotFig6.m to create plots shown in Figure 6\n');

fprintf('For the Sun:\n');
params_sun.band_order = -1; % Band V is at longer wavelengths than band B.
params_sun.lmin = 7e-8; % Plot minimum wavelength in meters
params_sun.lmax = 4e-6; % Plot maximum wavelength in meters
params_sun.plotlist = [false, true, false]; % this controls which plots
    % will be generated. Change it to [true, true, true] to see all plots.
params_sun.plotlistprintpdf = [false, true, false]; % this controls which
    % plots will be saved to .pdf files. Change this to [true, true, true]
    % and also plotlist to [true, true, true] save all plots to disk.
params_sun.figscreenoffset = [0 4];
params_sun.plotpos = [0.21 0.17 0.78 0.76]; % normalized plot position
    % inside the figure, for Matlab.
if isoctave()
    % Octave has different fonts, so we need other parameters
    params_sun.plotpos = [0.24 0.18 0.75 0.72]; 
end
params_sun.figpath = 'outputs/'; % Folder
outputs_sunBV = calc_star_celb('Sun',...
    'calspec/sun_reference_stis_002.fits', 'V', 'B', params_sun);


fprintf('\nFor Vega:\n');
params_Vega.band_order = -1; % Band V is at longer wavelengths than band B.
params_Vega.lmin = 7e-8; % Plot minimum wavelength in meters
params_Vega.lmax = 4e-6; % Plot maximum wavelength in meters
params_Vega.plotlist = [false, true, false]; % this controls which plots
    % will be generated. Change it to [true, true, true] to see all plots.
params_Vega.plotlistprintpdf = [false, true, false]; % this controls which
    % plots will be saved to .pdf files. Change this to [true, true, true]
    % and also plotlist to [true, true, true] save all plots to disk.
params_Vega.figscreenoffset = [3.5 4];
params_Vega.plotpos = [0.14 0.17 0.85 0.76]; % for Matlab
if isoctave()
    params_Vega.plotpos = [0.25 0.18 0.74 0.71]; % for Octave
end
params_Vega.figpath = 'outputs/';
outputs_VegaBV = calc_star_celb('Vega',...
    'calspec/alpha_lyr_stis_008.fits', 'V', 'B', params_Vega);


disp('Done.');